pub struct ChequeWithdrawBuilder {
    pub out_points: Vec<OutPoint>,
    pub sender_lock_script: Script,
    pub acp_script_id: Option<ScriptId>,
}

Fields

out_points: Vec<OutPoint>

The cheque cells to withdraw, all cells must have same lock script and same type script and cell data length is equals to 16.

sender_lock_script: Script

Sender’s lock script, must be a sighash address, and the script hash must match the cheque cell’s lock script args.

acp_script_id: Option<ScriptId>

If acp_script_id provided, will withdraw to anyone-can-pay address

Implementations