pub enum SinceSource {
LockArgs(usize),
Value(u64),
}Variants
LockArgs(usize)
The vaule in the tuple is offset of the args, and the since is stored in lock.args[offset..offset+8]
Value(u64)
raw since value