Enum ckb_sdk::tx_builder::TransferAction
source · pub enum TransferAction {
Create,
Update,
}Variants
Create
This action will crate a new cell, typecial lock script: cheque, sighash, multisig
Update
This action will query the exists cell and update the amount, typecial lock script: acp