pub struct CapacityBalancer {
    pub fee_rate: FeeRate,
    pub capacity_provider: CapacityProvider,
    pub change_lock_script: Option<Script>,
    pub force_small_change_as_fee: Option<u64>,
}
Transaction capacity balancer config

Fields

fee_rate: FeeRatecapacity_provider: CapacityProvider

Search cell by this lock script and filter out cells with data or with type script or not mature.

change_lock_script: Option<Script>

Change cell’s lock script if None use capacity_provider’s first lock script

force_small_change_as_fee: Option<u64>

When there is no more inputs for create a change cell to balance the transaction capacity, force the addition capacity as fee, the value is actual maximum transaction fee.

Implementations

Create new simple capacity balancer with since source.

Set or clear the force_small_change_as_fee