Struct ckb_sdk::types::ScriptGroup
source · pub struct ScriptGroup {
pub script: Script,
pub group_type: ScriptGroupType,
pub input_indices: Vec<usize>,
pub output_indices: Vec<usize>,
}Expand description
A script group is defined as scripts that share the same hash.
A script group will only be executed once per transaction, the script itself should check against all inputs/outputs in its group if needed.
Fields
script: ScriptThe script.
A script group is a group of input and output cells that share the same script.
group_type: ScriptGroupTypeThe script group type.
input_indices: Vec<usize>Indices of input cells.
output_indices: Vec<usize>Indices of output cells.
Implementations
sourceimpl ScriptGroup
impl ScriptGroup
sourcepub fn new(script: &Script, group_type: ScriptGroupType) -> Self
pub fn new(script: &Script, group_type: ScriptGroupType) -> Self
Creates a new script group struct.
sourcepub fn from_lock_script(script: &Script) -> Self
pub fn from_lock_script(script: &Script) -> Self
Creates a lock script group.
sourcepub fn from_type_script(script: &Script) -> Self
pub fn from_type_script(script: &Script) -> Self
Creates a type script group.